# RawOpenTicketAIConfig

| Attribute                                  | type                                                 | required | default                                                | description                                                    |
|--------------------------------------------|------------------------------------------------------|----------|--------------------------------------------------------|----------------------------------------------------------------|
| `plugins`                                  | array of any                                         |          |                                                        | Plugins                                                        |
| `plugins[]`                                | any                                                  |          |                                                        |                                                                |
| `services`                                 | array of [RenderableConfig](#renderableconfig)       |          |                                                        | Services                                                       |
| `services[]`                               | object                                               |          |                                                        | RenderableConfig                                               |
| `services[].uid`                           | any                                                  |          |                                                        | Uid                                                            |
| `services[].id`                            | any                                                  | ✓        |                                                        | Id                                                             |
| `services[].use`                           | any                                                  |          | `open_ticket_ai.base.CompositePipe`                    | Use                                                            |
| `services[].injects`                       | object                                               |          |                                                        | Injects                                                        |
| `services[].params`                        | object                                               |          |                                                        | Params                                                         |
| `orchestrator`                             | object                                               |          |                                                        | OrchestratorConfig                                             |
| `orchestrator.runners`                     | array of [RunnerDefinition](#runnerdefinition)       |          |                                                        | Runners                                                        |
| `orchestrator.runners[]`                   | object                                               |          |                                                        | RunnerDefinition                                               |
| `orchestrator.runners[].id`                | any or any                                           |          | `null`                                                 | Id                                                             |
| `orchestrator.runners[].on`                | array of [TriggerConfig](#triggerconfig)             | ✓        |                                                        | On                                                             |
| `orchestrator.runners[].on[]`              | object                                               | ✓        |                                                        | TriggerConfig                                                  |
| `orchestrator.runners[].on[].uid`          | any                                                  |          |                                                        | Uid                                                            |
| `orchestrator.runners[].on[].id`           | any                                                  | ✓        |                                                        | Id                                                             |
| `orchestrator.runners[].on[].use`          | any                                                  |          | `open_ticket_ai.base.CompositePipe`                    | Use                                                            |
| `orchestrator.runners[].on[].injects`      | object                                               |          |                                                        | Injects                                                        |
| `orchestrator.runners[].on[].params`       | object                                               |          |                                                        | Params                                                         |
| `orchestrator.runners[].run`               | object                                               | ✓        |                                                        | PipeConfig                                                     |
| `orchestrator.runners[].run.uid`           | any                                                  |          |                                                        | Uid                                                            |
| `orchestrator.runners[].run.id`            | any                                                  | ✓        |                                                        | Id                                                             |
| `orchestrator.runners[].run.use`           | any                                                  |          | `open_ticket_ai.base.CompositePipe`                    | Use                                                            |
| `orchestrator.runners[].run.injects`       | object                                               |          |                                                        | Injects                                                        |
| `orchestrator.runners[].run.params`        | object                                               |          |                                                        | Params                                                         |
| `orchestrator.runners[].run.if`            | any or any                                           |          | `True`                                                 | If                                                             |
| `orchestrator.runners[].run.depends_on`    | array of any                                         |          |                                                        | List of dependencies, which must be executed before this step. |
| `orchestrator.runners[].run.depends_on[]`  | any                                                  |          |                                                        |                                                                |
| `orchestrator.runners[].run.steps`         | array of [PipeConfig](#pipeconfig) or any            |          | `null`                                                 | Steps                                                          |
| `infrastructure`                           | object                                               | ✓        |                                                        | InfrastructureConfig                                           |
| `infrastructure.logging`                   | object                                               |          |                                                        | LoggingConfig                                                  |
| `infrastructure.logging.level`             | enum `DEBUG`, `INFO`, `WARNING`, `ERROR`, `CRITICAL` |          | `INFO`                                                 | Level                                                          |
| `infrastructure.logging.log_to_file`       | any                                                  |          | `False`                                                | Log To File                                                    |
| `infrastructure.logging.log_file_path`     | any or any                                           |          | `null`                                                 | Log File Path                                                  |
| `infrastructure.logging.log_format`        | any                                                  |          | `%(asctime)s - %(name)s - %(levelname)s - %(message)s` | Log Format                                                     |
| `infrastructure.logging.date_format`       | any                                                  |          | `%Y-%m-%d %H:%M:%S`                                    | Date Format                                                    |
| `infrastructure.default_template_renderer` | any                                                  | ✓        |                                                        | Default Template Renderer                                      |
